@@ -134,7 +134,7 @@ class GetEntryRelationsRequest():
     deeplevel: int = 1
 
 class GetEntryResponse(HasEntry):
-    pass
+    attributeId: int
 
 class EntryService(ApiMethods):
     def __init__(self, auth: Token):
@@ -183,6 +183,7 @@ class EntryService(ApiMethods):
 
         result = GetEntryResponse()            
         result.entry = response['result'].get('entry')
+        result.attributeId = response['result'].get('attributeId')
         return result
 
 
